@@ -4,7 +4,7 @@ use 5.024;
 use warnings;
 use utf8;
 
-our $VERSION = "0.9904";
+our $VERSION = "0.9905";
 
 =encoding utf-8
 
@@ -24,10 +24,20 @@ B<greple> B<-Mcharcode> [ I<module option> ] -- [ I<command option> ] ...
 
   COMMAND OPTION
     --no-annotate  do not print annotation
+    --[no-]align   align annotations
+    --align-all    align to the same column for all lines
+    --align-side   align to the longest line
+
+  UNICODE
     --composite    find composite character (combining character sequence)
     --precomposed  find precomposed character
-    --combind      find both composite and precomposed characters
+    --combined     find both composite and precomposed characters
     --dt=type      specify decomposition type
+    --surrogate    find character in UTF-16 surrogate pair range
+    --outstand     find non-ASCII combining characters
+    -p/-P prop     find \p{prop} or \P{prop} characters
+
+  ANSI
     --ansicode     find ANSI terminal control sequences
 
   MODULE OPTION
@@ -38,14 +48,14 @@ B<greple> B<-Mcharcode> [ I<module option> ] -- [ I<command option> ] ...
     --[no-]name    display character name
     --[no-]visible display character name
     --[no-]split   put annotattion for each character
-    --align=#      align annotation
+    --alignto=#    align annotation to #
 
     --config KEY[=VALUE],...
              (KEY: column char width code name visible align)
 
 =head1 VERSION
 
-Version 0.9904
+Version 0.9905
 
 =head1 DESCRIPTION
 
@@ -98,12 +108,22 @@ character.  This module allows you to see how it is done.
 Print annotation or not.  Enabled by default, so use C<--no-annotate>
 to disable it.
 
+=item B<-->[B<no->]B<align>
+
+Align annotation or not.
+Default true.
+
+=item B<--align-all>
+
+Align to the same column for all lines
+
+=item B<--align-side>
+
+Align to the longest line length, regardless of match position.
+
 =back
 
-=head2 CHARACTER CODE OPTIONS
-
-The following options are used to search for Unicode combining
-characters.
+=head1 PATTERN OPTIONS
 
 If multiple patterns are given to B<greple>, it normally prints only
 the lines that match all of the patterns.  However, for the purposes
@@ -124,7 +144,7 @@ composed of base and combining characters.
 
 Search for precomposed characters (C<\p{Dt=Canonical}>).
 
-=item B<--combind>
+=item B<--combined>
 
 Find both B<composite> and B<precomposed> characters.
 
@@ -133,6 +153,23 @@ Find both B<composite> and B<precomposed> characters.
 Specifies the C<Decomposition_Type>.  It can take three values:
 C<Canonical>, C<Non_Canonical> (C<NonCanon>), or C<None>.
 
+=item B<--outstand>
+
+Matches outstanding characters, those are non-ASCII combining
+characters.
+
+=item B<--surrogate>
+
+Matches to characters in UTF-16 surragate pair range (U+10000 to
+U+10FFFF).
+
+=item B<-p> I<prop>, B<-P> I<prop>
+
+Short cut for C<-E '\p{prop}'> and  C<-E '\P{prop}'>.
+
+You will not be able to use greple's C<-p> option, but it probably
+won't be a problem.  If you must use it, use C<--pargraph>.
+
 =item B<--ansicode>
 
 Search ANSI terminal control sequence.  Automatically disables C<name>
@@ -142,14 +179,12 @@ disabled too.
 To be precise, it searches for CSI Control sequences defined in
 ECMA-48.  Pattern is defined as this.
 
-    define ECMA-CSI <<EOL
-        (?x)
-        # see ECMA-48 5.4 Control sequences
-        (?: \e\[ | \x9b ) # csi
-        [\x30-\x3f]*      # parameter bytes
-        [\x20-\x2f]*      # intermediate bytes
-        [\x40-\x7e]       # final byte
-    EOL
+    (?x)
+    # see ECMA-48 5.4 Control sequences
+    (?: \e\[ | \x9b ) # csi
+    [\x30-\x3f]*      # parameter bytes
+    [\x20-\x2f]*      # intermediate bytes
+    [\x40-\x7e]       # final byte
 
 =for html <p>
 <img width="750" src="https://raw.githubusercontent.com/kaz-utashiro/greple-charcode/refs/heads/main/images/ansicode.png">
@@ -157,41 +192,67 @@ ECMA-48.  Pattern is defined as this.
 
 =back
 
-=head1 MODULE OPTIONS
+=head1 MODULE OPTIONS and PARAMS
+
+Module-specific options are specified between C<-Mcharcode> and C<-->.
+
+    greple -Mcharcode --config width,name=0 -- ...
+
+Parameters can be set in two ways, one using the C<--config> option
+and the other using dedicated options.  See the L</CONFIGURATION>
+section for more information.
 
 =over 7
 
+=item B<--config>=I<params>
+
+Set configuration parameters.
+
+=item B<column>
+
 =item B<-->[B<no->]B<column>
 
 Show column number.
-Default B<true>.
+Default C<1>.
+
+=item B<char>
 
 =item B<-->[B<no->]B<char>
 
 Show the character itself.
-Default B<false>.
+Default C<0>.
+
+=item B<width>
 
 =item B<-->[B<no->]B<width>
 
 Show the width.
-Default B<false>.
+Default C<0>.
+
+=item B<code>
 
 =item B<-->[B<no->]B<code>
 
 Show the character code in hex.
-Default B<true>.
+Default C<1>.
+
+=item B<name>
 
 =item B<-->[B<no->]B<name>
 
 Show the Unicode name of the character.
-Default B<true>.
+Default C<1>.
+
+=item B<visible>
 
 =item B<-->[B<no->]B<visible>
 
 Display invisible characters in a visible string representation.
-Default False.
+Default C<0>.
 
-=item B<--align>=I<column>
+=item B<alignto>=I<column>
+
+=item B<--alignto>=I<column>
 
 Align annotation messages.  Defaults to C<1>, which aligns to the
 rightmost column; C<0> means no align; if a value of C<2> or greater
@@ -201,6 +262,8 @@ I<column> can be negative; if C<-1> is specified, align to the same
 column for all lines.  If C<-2> is specified, align to the longest
 line length, regardless of match position.
 
+=item B<split>
+
 =item B<-->[B<no->]B<split>
 
 If a pattern matching multiple characters is given, annotate each
@@ -217,56 +280,24 @@ Configuration parameters can be set in several ways.
 The start function of a module can be specified at the same time as
 the module declaration.
 
-    greple -Mcharcode::config(width,name=0)
+    greple -Mannotate::config(alignto=0)
 
-    greple -Mcharcode::config=width,name=0
+    greple -Mannotate::config=alignto=80
 
 =head2 PRIVATE MODULE OPTION
 
-Module-specific options are specified between C<-Mcharcode> and C<-->.
+Module-specific options are specified between C<-Mannotate> and C<-->.
 
-    greple -Mcharcode --config width,name=0 -- ...
+    greple -Mannotate --config alignto=80 -- ...
 
-=head1 CONFIGURATION PARAMETERS
+    greple -Mannotate --alignto=80 -- ...
 
-=over 7
+=head2 GENERIC MODULE OPTION
 
-=item B<column>
+Module-specific C<---config> option can be called by normal command
+line option C<--annotate::config>.
 
-(default 1)
-Show column number.
-
-=item B<char>
-
-(default 0)
-Show the character itself.
-
-=item B<width>
-
-(default 0)
-Show the width.
-
-=item B<code>
-
-(default 1)
-Show the character code in hex.
-
-=item B<name>
-
-(default 1)
-Show the Unicode name of the character.
-
-=item B<visible>
-
-(default 0)
-Display invisible characters in a visible string representation.
-
-=item B<align>=I<column>
-
-(default 1)
-Align the description on the same column.
-
-=back
+    greple -Mannotate --annotate::config alignto=80 ...
 
 =head1 INSTALL
 
@@ -302,16 +333,16 @@ use App::Greple::annotate;
 our $opt_annotate = 0;
 
 our $config = Getopt::EX::Config->new(
-    column   => 1,
-    char     => 0,
-    width    => 0,
-    visible  => 1,
-    code     => 0,
-    name     => 1,
-    align    => \$App::Greple::annotate::config->{align},
-    split    => \$App::Greple::annotate::config->{split},
+    column  => 1,
+    char    => 0,
+    width   => 0,
+    visible => 1,
+    code    => 0,
+    name    => 1,
+    alignto => \$App::Greple::annotate::config->{alignto},
+    split   => \$App::Greple::annotate::config->{split},
 );
-my %type = ( align => '=i', '*' => '!' );
+my %type = ( alignto => '=i', '*' => '!' );
 lock_keys %{$config};
 
 sub finalize {
@@ -403,19 +434,25 @@ $App::Greple::annotate::ANNOTATE = \&annotate;
 
 __DATA__
 
-option --load-annotate -Mannotate
-
 option default \
+    -Mannotate \
     --need=1 \
-    --fs=once --ls=separate $<move> --load-annotate
+    --fs=once --ls=separate $<move>
+
+option --charcode::config \
+    --prologue &__PACKAGE__::config($<shift>)
+
+option --config --charcode::config
+
+option --surrogate -E '[\N{U+10000}-\N{U+10FFFF}]'
 
 define \p{CombinedChar} \p{Format}\p{Mark}
 define \p{Combined}     [\p{CombinedChar}]
 define \p{Base}         [^\p{CombinedChar}]
 
-option --composite -E '(\p{Base})(\p{Combined}+)'
+option --composite -E '(?#composite)(\p{Base})(\p{Combined}+)'
 
-option --decomposition-type -E '\p{Decomposition_Type=$<shift>}'
+option --decomposition-type -E '(?#canonical)\p{Decomposition_Type=$<shift>}'
 option --dt --decomposition-type
 
 option --precomposed --decomposition-type=Canonical
@@ -425,14 +462,14 @@ option --combined \
     --precomposed --composite
 
 option --outstand \
-    --combined -E '(?=\P{ASCII})\X'
+    --combined -E '(?#outstand)(?=\P{ASCII})\X'
 
 define ANSI-CSI <<EOL
     (?xn)
     # see ANSI-48 5.4 Control sequences
     ( \e\[ | \x9b )	# csi
-    [\x30-\x3f]*	# parameter bytes
-    [\x20-\x2f]*	# intermediate bytes
+    [\x30-\x3f]*+	# parameter bytes
+    [\x20-\x2f]*+	# intermediate bytes
     [\x40-\x7e]		# final byte
 EOL
 
@@ -443,11 +480,11 @@ define ANSI-RESET <<EOL
 EOL
 
 expand --visible-option \
-    -Mcharcode --config code=0,name=0,visible=1 -- \
+    --charcode::config code=0,name=0,visible=1 \
     --cm=N
 
 option --ansicode \
-    --visible-option -E '(?:ANSI-RESET)+|(?:ANSI-CSI)'
+    --visible-option -E '(?#ansicode)(?:ANSI-RESET)+|(?:ANSI-CSI)'
 
 option --ansicode-each \
     --visible-option -E ANSI-CSI
@@ -455,5 +492,5 @@ option --ansicode-each \
 option --ansicode-seq \
     --visible-option -E '(?:ANSI-CSI)+'
 
-option --charcode::config --prologue &__PACKAGE__::config($<shift>)
-option --config --charcode::config
+option -p -E '\p{$<shift>}'
+option -P -E '\P{$<shift>}'
